==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-hungarian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Neved");
define("_OK","Ok!");
define("_COMMENT","hozzszls");
define("_CONFIGURE","Belltsok");
define("_LOGINCREATE","Belps/Regisztrci");
define("_THRESHOLD","Kszb");
define("_NOCOMMENTS","Nincs hozzszls!");
define("_NESTED","Begyazott");
define("_FLAT","Sima");
define("_THREAD","Szl");
define("_OLDEST","A legrgebbi fell");
define("_NEWEST","A legrgebbi alul");
define("_HIGHEST","A legolvasottabb fell");
define("_COMMENTSWARNING","Minden hozzszls a szerzk tulajdona. Nem felttlenl rtnk egyet velk, s nem vllalhatunk felelssget a hozzszlsok tartalmrt.");
define("_SCORE","Pontok:");
define("_USERINFO","Adatok");
define("_READREST","A hozzszls folytatsa...");
define("_REPLY","Vlasz");
define("_REPLYMAIN","j hozzszls");
define("_NOSUBJECT","Cm nlkl");
define("_NOANONCOMMENTS","Nvtelenl nem lehet hozzszlni, krjk <a href=\"modules.php?name=Your_Account\">regisztrlj</a>");
define("_PARENT","Szl");
define("_ROOT","Gykr");
define("_UCOMMENT","Hozzszls");
define("_ALLOWEDHTML","Megengedett HTML:");
define("_POSTANON","Nvtelen hozzszls");
define("_EXTRANS","HTML kdok eltvoltsa");
define("_HTMLFORMATED","HTML formzott szveg");
define("_PLAINTEXT","Formzatlan szveg");
define("_ONN","...");
define("_SUBJECT","Cm");
define("_SURVEYCOM","Hozzszls a szavazshoz");
define("_SURVEYCOMPRE","Megtekints elklds eltt");
define("_NOTRIGHT","Hiba lpett fel egy vltoz tadsakor. Ez az zenet csak arra szolgl, hogy ksbb ne keveredjenek ssze a dolgok...");
define("_DIRECTCOM","Kzvetlen hozzszls...");
define("_SENDAMSG","zenet kldse");
define("_PASTSURVEYS","Korbbi szavazsok");



define("_LVOTES","szavazat");
define("_TOTALVOTES","sszes szavazat:");
define("_VOTING","Szavazgp");
define("_OTHERPOLLS","Ms szavazsok");
define("_CURRENTSURVEY","Az aktulis szavazs");
define("_CURRENTPOLLRESULTS","Az aktulis szavazs eredmnye");
define("_PREVIEW","Elnzet");
define("_REFRESH","Frissts");
define("_SURVEYS","Szavazsok");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-hungarian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_YOURNAME","Neved");
define("_OK","Ok!");
define("_COMMENT","hozzszls");
define("_CONFIGURE","Belltsok");
define("_LOGINCREATE","Belps/Regisztrci");
define("_THRESHOLD","Kszb");
define("_NOCOMMENTS","Nincs hozzszls!");
define("_NESTED","Begyazott");
define("_FLAT","Sima");
define("_THREAD","Szl");
define("_OLDEST","A legrgebbi fell");
define("_NEWEST","A legrgebbi alul");
define("_HIGHEST","A legolvasottabb fell");
define("_COMMENTSWARNING","Minden hozzszls a szerzk tulajdona. Nem felttlenl rtnk egyet velk, s nem vllalhatunk felelssget a hozzszlsok tartalmrt.");
define("_SCORE","Pontok:");
define("_USERINFO","Adatok");
define("_READREST","A hozzszls folytatsa...");
define("_REPLY","Vlasz");
define("_REPLYMAIN","j hozzszls");
define("_NOSUBJECT","Cm nlkl");
define("_NOANONCOMMENTS","Nvtelenl nem lehet hozzszlni, krjk <a href=\"modules.php?name=Your_Account\">regisztrlj</a>");
define("_PARENT","Szl");
define("_ROOT","Gykr");
define("_UCOMMENT","Hozzszls");
define("_ALLOWEDHTML","Megengedett HTML:");
define("_POSTANON","Nvtelen hozzszls");
define("_EXTRANS","HTML kdok eltvoltsa");
define("_HTMLFORMATED","HTML formzott szveg");
define("_PLAINTEXT","Formzatlan szveg");
define("_ONN","...");
define("_SUBJECT","Cm");
define("_SURVEYCOM","Hozzszls a szavazshoz");
define("_SURVEYCOMPRE","Megtekints elklds eltt");
define("_NOTRIGHT","Hiba lpett fel egy vltoz tadsakor. Ez az zenet csak arra szolgl, hogy ksbb ne keveredjenek ssze a dolgok...");
define("_DIRECTCOM","Kzvetlen hozzszls...");
define("_SENDAMSG","zenet kldse");
define("_PASTSURVEYS","Korbbi szavazsok");



define("_LVOTES","szavazat");
define("_TOTALVOTES","sszes szavazat:");
define("_VOTING","Szavazgp");
define("_OTHERPOLLS","Ms szavazsok");
define("_CURRENTSURVEY","Az aktulis szavazs");
define("_CURRENTPOLLRESULTS","Az aktulis szavazs eredmnye");
define("_PREVIEW","Elnzet");
define("_REFRESH","Frissts");
define("_SURVEYS","Szavazsok");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>
